@@ -10,10 +10,13 @@
    file_mini_csv
    dir_scrnaseq_cellranger
    generate_cell_ranger_files
+   df_iris
    anndata_mouse_sc_lymph_node
    anndata_human_immune_cells
    anndata_pbmc68k_reduced
    anndata_pbmc3k_processed
+   anndata_with_obs
+   fake_bio_notebook_titles
 """
 
 from ._core import (
@@ -21,6 +24,8 @@ from ._core import (
     anndata_mouse_sc_lymph_node,
     anndata_pbmc3k_processed,
     anndata_pbmc68k_reduced,
+    anndata_with_obs,
+    df_iris,
     dir_scrnaseq_cellranger,
     file_bam,
     file_fastq,
@@ -29,3 +34,4 @@ from ._core import (
     file_mini_csv,
     generate_cell_ranger_files,
 )
+from ._fake import fake_bio_notebook_titles
